import harkpython.harkbasenode as harkbasenode
import numpy
import pylab


class HarkNode (harkbasenode.HarkBaseNode):
    def __init__(self):
        self.outputNames = ("output",)
        self.outputTypes = ("prim_int",)
        pylab.ion()
        pylab.hold(False)

        # plot width in samples
        self.width = 512
        self.zrange = [-1, 1]

    def calculate(self):
        data = 20 * numpy.log10(abs(numpy.array(self.input) + 1))

        # Update buffer
        if self.count == 0:
            self.buffer = data[0, :]
        else:
            self.buffer = numpy.c_[self.buffer, data[0, :]][:, -self.width:]

        # Update plot for every 100 counts (= 1 sec)
        if (self.count + 1) % 100 == 0:
            #  update vmax/vmin 
            self.zrange[0] = max(self.zrange[0], self.buffer.max())
            self.zrange[1] = min(self.zrange[1], self.buffer.min())

            # plot spectrum
            pylab.clf()
            pylab.imshow(numpy.flipud(self.buffer), aspect="auto",
                         vmax=self.zrange[0],
                         vmin=self.zrange[1])
            pylab.colorbar()
            pylab.draw()

        # Dummy output
        self.outputValues["output"] = 0
